@@ -6,7 +6,7 @@ use warnings;
 use Params::Util   1.00 ();
 use ORLite::Mirror 1.20 ();
 
-our $VERSION = '1.06';
+our $VERSION = '1.07';
 
 sub import {
 	my $class  = shift;
@@ -23,4 +23,19 @@ sub import {
 	return 1;
 }
 
+sub age {
+	my $class = shift;
+
+	# Find the most recent upload
+	my @latest = ORDB::CPANUploads::Uploads->select(
+		'ORDER BY released DESC LIMIT 1',
+	);
+	unless ( @latest == 1 ) {
+		die "Unexpected number of uploads";
+	}
+
+	# Compare to the current time
+	return time - $latest[0]->released;
+}
+
 1;
